<template>
  <div class="fullheight">
    <div
      class="tree-box"
      @click="boxLeftClick"
      :class="ishaveborder ? 'border' : ''"
    >
      <el-tree
        :data="treeData"
        :props="props"
        :load="loadNode"
        @node-click="handleNodeClick"
        @node-expand="handleExpand"
        lazy
        node-key="id"
        ref="tree"
        highlight-current
      >
        <span class="custom-tree-node" slot-scope="{node}">
          <div>
            <i class="el-icon-s-order icon"></i>
            <span style="padding-left: 4px;">{{ node.label }}</span>
          </div>
          <!-- <i
            class='el-icon-more'
            @click='moreClick(node, data)'
          >
            <el-card class='card-box'>
              <el-button
                type='text'
                size="small"
                icon='el-icon-delete'
              >
                删除
              </el-button>
            </el-card>
          </i> -->
        </span></el-tree
      >
    </div>

    <div class="right-box" @click="boxRightClick">
      <ht-table
        @load="loadData"
        :data="data"
        ref="htTable"
        :pageResult="pageResult"
        :selection="true"
        :show-custom-column="false"
        :show-export="false"
        @row-dblclick="handleEdit"
        quick-search-props="subjectCode"
      >
        <template v-slot:toolbar>
          <el-button
            size="small"
            type="primary"
            @click="handleAdd"
            icon="el-icon-plus"
            v-methodauth="'courseDetails_add'"
            >添加</el-button
          >
          <!-- v-methodauth="courseDetails_add" -->
          <ht-delete-button
            :url="deleteUrl"
            :htTable="$refs.htTable"
            @after-delete="afterDelete"
            v-methodauth="'courseDetails_remove'"
            >删除</ht-delete-button
          >
          <!-- v-methodauth="courseDetails_remove" -->
        </template>
        <template>
          <ht-table-column
            prop="subjectCode"
            label="科目编码"
            align="center"
            show-overflow-tooltip
          >
          </ht-table-column>
          <ht-table-column
            prop="subjectName"
            label="科目名称"
            align="center"
            show-overflow-tooltip
          >
          </ht-table-column>
          <ht-table-column
            prop="companyName"
            align="center"
            label="所属公司名称"
            show-overflow-tooltip
          >
          </ht-table-column>
        </template>
      </ht-table>
      <el-dialog
        :title="type === 'add' ? '【成本科目】添加' : '【成本科目】修改'"
        :visible.sync="dialogVisible"
        width="600px"
        :before-close="handleClose"
        :close-on-click-modal="false"
        top="8vh"
        v-loading="loading"
        element-loading-text="拼命加载中"
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(0, 0, 0, 0.8)"
      >
        <el-form
          ref="form"
          v-form
          :model="form"
          :rules="rules"
          label-width="80px"
          v-if="dialogVisible"
        >
          <el-row>
            <el-col :span="24">
              <el-form-item label="科目名称" prop="subjectName">
                <el-input
                  v-model="form.subjectName"
                  placeholder="科目名称"
                ></el-input>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="24">
              <el-form-item label="科目编码" prop="subjectCode">
                <el-input
                  v-model="form.subjectCode"
                  placeholder="科目编码"
                  :disabled="disabledSubCode"
                ></el-input>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="24">
              <el-form-item label="所属公司" prop="companyIds">
                <company-info-selector
                  v-model="form.companyName"
                  :valueName="form.companyIds"
                  @handleChanged="handleChanged"
                  @value="companyValue"
                />
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-col :span="24">
              <el-form-item label="路段名称" prop="roadSegmentName">
                <el-select
                  v-model="form.roadSegmentId"
                  placeholder="请选择路段"
                  clearable
                  style="width:100%"
                  @change="handleRoadNameChange"
                  @clear="handleRoadNameClear"
                >
                  <el-option
                    v-for="item in roadData"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                  >
                  </el-option>
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
        </el-form>
        <span slot="footer" class="dialog-footer">
          <el-button @click="handleCancel">取 消</el-button>
          <el-button type="primary" @click="handleSubmit">保存</el-button>
        </span>
        <!-- <el-dialog
        :visible.sync="loadingDialogVisible"
        v-loading="loading"
        element-loading-text="拼命加载中"
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(0, 0, 0, 0.8)"
      ></el-dialog> -->
      </el-dialog>
    </div>
  </div>
</template>
<script>
import req from '@/request.js'
import basicData from '@/api/basicData.js'
import eipOrgSelector from '@/components/eipControl/selector/EipOrgSelector.vue'
import companyInfoSelector from '@/components/selector/companyInfoSelector.vue'
export default {
  components: {
    // eipOrgSelector,
    companyInfoSelector
  },
  data() {
    return {
      props: {
        label: 'name',
        code: 'code',
        id: 'id',
        children: 'children',
        pcode: 'pcode',
        isLeaf: 'leaf' // 指定节点是否为叶子节点，仅在指定了 lazy 属性的情况下生效
      },
      data: [],
      pageResult: {
        page: 1,
        pageSize: 10,
        total: 0
      },
      pcode: '', //根据父节点获取子节点
      pcodeData: '', //添加时父节点数据，用于保存
      dialogVisible: false,
      type: '', //add, edit
      form: {
        pcode: '',
        pname: '',
        // companyName: '',
        roadSegmentId: ''
      },
      ishaveborder: false, //控制树形控件的边框颜色
      node: '',
      resolve: '',
      treeData: [],
      nodeKey: false,
      roadData: [],
      loading: false,
      companyObj: '',
      disabledSubCode: false,
      rules: {
        subjectCode: {
          required: true,
          message: '请输入科目编码',
          trigger: 'blur'
        },
        companyName: {
          required: true,
          message: '请选择所属公司',
          trigger: 'blur'
        },
        subjectName: {
          required: true,
          message: '请输入科目名称',
          trigger: 'blur'
        },
        pcode: {
          required: true,
          message: '请输入科目名称',
          trigger: 'blur'
        }
      },
      arrPcode: [
        {
          name: '成本科目汇总',
          code: 'root'
        }
      ]
    }
  },
  computed: {
    deleteUrl: function() {
      return window.context.yhxt + '/bizCourseDetails/v1/updateCourseDetails'
    }
  },
  created() {
    this.roadData = this.getroad()
  },
  methods: {
    getroad() {
      let arr = []
      basicData.getRoadManagement().then(res => {
        res.rows.forEach(item => {
          arr.push({
            name: item.name,
            id: item.id
          })
        })
        // console.log(arr, 'dddddddddd')
      })
      return arr
    },
    loadNode(node, resolve) {
      //暂存
      if (node.level === 0) {
        this.node = node
        this.resolve = resolve
        return resolve(this.arrPcode)
      } else {
        //获取子节点
        this.getCostAccount(node.data.code, resolve)
      }
      // if (node && resolve) {
      //   this.node = node
      //   this.resolve = resolve
      // } else {
      //   this.node.level = 0
      //   node = this.node
      //   resolve = this.resolve
      // }
      // //暂存
      // if (node.level === 0) {
      //   // this.getCostAccount('root', resolve)
      //   return resolve(this.arrPcode)
      // }
      // if (node.level >= 1) {
      //   this.nodeKey = false
      //   //获取子节点
      //   // console.log(node)
      //   this.getCostAccount(node.data.code, resolve)
      //   return resolve([])
      // }
    },
    //获取第一层节点
    getCostAccount(query, resolve) {
      basicData.getCostAccountManagement(query).then(res => {
        let data = []
        res.data.forEach(item => {
          if (item.hasChildren == 'true') {
            data.push({
              name: item.subjectName,
              code: item.subjectCode,
              id: item.id
            })
          } else {
            data.push({
              name: item.subjectName,
              code: item.subjectCode,
              id: item.id,
              leaf: true //没有子节点时为true
            })
          }
        })
        if (this.nodeKey) {
          this.treeData = data
        } else {
          resolve(data)
        }
      })
    },
    loadData(param, cb) {
      // console.log(param)
      if (this.pcode) {
        let querys = []
        querys.push({
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'pcode',
          relation: 'AND',
          value: this.pcode
        })
        param.querys = querys
      }
      this.$http
        .post('${yhxt}/bizCourseDetails/v1/getJson', param)
        .then(res => {
          let result = res.data
          this.data = result.rows
          this.pageResult = {
            page: result.page,
            pageSize: result.pageSize,
            total: result.total
          }
        })
        .finally(() => cb())
    },
    //根据id查询详情
    getById(id) {
      this.$http.get('${yhxt}/bizCourseDetails/v1/get/' + id).then(res => {
        this.data = [res.data]
        this.pageResult = {
          page: 1,
          pageSize: 10,
          total: 1
        }
      })
    },
    //点击节点
    handleNodeClick(data) {
      this.nodeKey = false
      //暂存父节点数据
      this.pcodeData = data
      this.form.pcode = data.code
      this.form.pname = data.name
      this.pcode = data.code
      // this.getById(data.id)
      if (data.leaf) {
        this.getById(data.id)
      } else {
        this.$refs.htTable.load()
      }
      // this.$refs.tree.setCurrentKey(data.id)
    },
    //节点展开触发事件
    handleExpand(data) {
      // this.pcodeData = data
      // this.form.pcode = data.code
      // this.form.pname = data.name
      // this.pcode = data.code
      // this.$refs.htTable.load()
    },
    afterDelete() {
      this.pcode = ''
      this.$refs.htTable.load()
      this.node.childNodes = []
      this.loadNode(this.node, this.resolve)
      // this.nodeKey = true
      // this.$refs.tree.load()
    },
    //添加
    handleAdd() {
      this.disabledSubCode = false
      this.form = {
        ...this.form,
        subjectCode: '',
        subjectName: '',
        // companyName: '',
        id: ''
      }
      this.type = 'add'
      this.form.roadSegmentId = this.roadData[0].id
      this.form.roadSegmentName = this.roadData[0].name
      if (this.pcodeData) {
        this.dialogVisible = true
      } else {
        this.dialogVisible = true
        this.form.pcode = 'root'
        this.form.pname = 'root'
      }
    },
    handleEdit(data) {
      let form = {
        // companyName: ''
      }
      this.type = 'edit'
      this.dialogVisible = true
      if (data.hasChildren == 'true') {
        this.disabledSubCode = true
      }
      this.form = {...form, ...data}
    },
    handleClose() {
      this.dialogVisible = false
    },
    handleCancel() {
      this.dialogVisible = false
    },
    handleSubmit() {
      console.log(this.form, '666666666666')
      this.$refs.form.validate(bool => {
        if (bool) {
          this.loading = true
          this.dialogVisible = true
          basicData.addCostAccountManagement(this.form).then(res => {
            this.$message.success(res.message)
            //将this.pcode清空
            this.pcode = ''
            this.dialogVisible = false
            this.loading = false
            this.$refs.htTable.load()
            this.node.childNodes = []
            this.loadNode(this.node, this.resolve)
            if (res.state) {
              setTimeout(() => {
                this.loading = false
              }, 10000)
            }
          })
        }
      })
    },
    //树形控件外围的盒子
    boxLeftClick() {
      this.ishaveborder = true
      this.form.pcode = 'root'
      this.form.pname = 'root'
    },
    boxRightClick() {
      this.ishaveborder = false
    },
    //鼠标右键事件
    moreClick(node, data) {
      console.log(data)
    },
    remove(node, data) {},
    //公司赋值
    handleChanged(obj) {
      // console.log(obj.valueInfo.join(','))
      this.form.companyIds = JSON.stringify(obj.valueInfo)
      this.form.companyName = obj.name
      this.form.companyId = obj.id
    },
    companyValue(obj) {
      this.companyObj = obj
      this.form.companyName = obj.name
      this.form.companyId = obj.id
      this.form.companyIds = JSON.stringify(obj.id.split(' ')) //必须是空格
    },
    handleRoadNameChange(id) {
      this.form.roadSegmentId = id
      this.roadData.forEach(item => {
        if (item.id == id) {
          this.form.roadSegmentName = item.name
        }
      })
    },
    handleRoadNameClear() {
      this.form.roadSegmentId = ''
      this.form.roadSegmentName = ''
    },
  }
}
</script>
<style lang="scss" scoped>
.fullheight {
  display: flex;
}
/deep/ .el-tree-node__content {
  background-color: #0f304f;
  color: #fff;
}
/deep/ .el-input-group__append {
  background-color: #114066;
  color: #fff;
  border: none;
}
/deep/ .el-tree-node:focus > .el-tree-node__content {
  background-color: #114066 !important;
}
.fullheight > div:nth-child(2) {
  border: none !important;
}
.tree-box {
  border: 1px solid #1a5d8b;
  width: 300px;
  height: 100%;
  overflow: auto;
  box-sizing: border-box;
  padding: 20px;
  font-size: 18px;
  .icon {
    color: #409fff;
    font-size: 18px;
  }
}
.right-box {
  width: calc(100% - 290px);
  margin-left: 10px;
  // border: 1px solid #eee;
  padding: 20px;
}
.custom-tree-node {
  flex: 1;
  display: flex;
  justify-content: space-between;
  align-items: center;
}
.el-icon-more {
  display: none;
}
.custom-tree-node:hover .el-icon-more {
  display: block;
  position: relative;
}
.card-box {
  display: none;
}
.el-icon-more:hover .card-box {
  display: block;
  top: 50px;
  left: -70px;
  widows: 60px;
}
// 树形控件高亮显示
.el-tree--highlight-current .el-tree-node.is-current > .el-tree-node__content {
  background-color: rgb(158, 245, 250) !important;
}
</style>
